#!/usr/bin/env python
import bcbio_postproc  # do not remove it: checking for python version and adding site dirs inside

from os.path import abspath, dirname, realpath, join
import sys
from source.utils import human_sorted


""" Input: Sorted and annotated BED file (i.e. at least 4 columns), File with list of key genes
    Output:
        BED file with no overlapped version of regions from input. In case of overlap scripts prefers 1) key gene,
        2) most upstream gene.

    Usage: python split_bed Input_BED_file [Key_genes_file] > Split_BED_file
"""


def _read_args(args):
    if len(args) < 1:
        log('Usage:\n')
        log('  ' + __file__ + ' Input_BED_file [Key_genes_file] > Split_BED_file\n')
        sys.exit(1)

    input_bed_fpath = abspath(args[0])
    log('Input: ' + input_bed_fpath)

    key_genes_fpath = '/ngs/reference_data/genomes/Hsapiens/common/az_key_genes.txt'
    if len(args) > 1:
        if args[1]:
            key_genes_fpath = abspath(args[1])
            log('Over-set key genes fpath: ' + key_genes_fpath)
    log()

    return input_bed_fpath, key_genes_fpath


def log(msg=''):
    sys.stderr.write(msg + '\n')


class Region:
    def __init__(self, entries):  # entries = line.strip().split('\t')
        self.chrom = entries[0]
        self.start = int(entries[1])
        self.end = int(entries[2])
        self.symbol = entries[3]
        self.rest = '\t'.join(entries[4:])

    def subregion(self, start=None, end=None):
        return Region([self.chrom, start if start else self.start, end if end else self.end, self.symbol, self.rest])

    def __str__(self):
        return '\t'.join([self.chrom, str(self.start), str(self.end), self.symbol, self.rest]) + '\n'

    def overlaps(self, other):  # assume 0-based coordinates!
        if self.chrom == other.chrom and self.end > other.start:
            return True
        return False

    def is_empty(self):
        return self.start == self.end

    @staticmethod
    def non_empty_list(regions):
        return [r for r in regions if not r.is_empty()]

    def split(self, other, key_genes):
        if self.end > other.end:  # other is fully included inside self
            if other.symbol in key_genes:  # note: two key genes can't overlap
                return Region.non_empty_list([self.subregion(end=other.start), other, self.subregion(start=other.end)])
            else:
                return Region.non_empty_list([self])
        else:
            if other.symbol in key_genes:  # note: two key genes can't overlap
                return Region.non_empty_list([self.subregion(end=other.start), other])
            else:
                return Region.non_empty_list([self, other.subregion(start=self.end)])

    def get_key(self):
        return '\t'.join([self.chrom, str(self.start), str(self.end)])

    def __lt__(self, other):
        # special case: chrM goes to the end
        if self.chrom != other.chrom and (self.chrom == 'chrM' or other.chrom == 'chrM'):
            return True if other.chrom == 'chrM' else False
        sorted_pair = human_sorted([self.get_key(), other.get_key()])
        if sorted_pair[0] == self.get_key() and sorted_pair[1] != self.get_key():
            return True
        return False


def main():
    input_bed_fpath, key_genes_fpath = _read_args(sys.argv[1:])

    key_genes = []
    with open(key_genes_fpath, 'r') as f:
        for line in f:
            key_genes.append(line.strip())

    input_regions = []
    with open(input_bed_fpath, 'r') as f:
        for line in f:
            if line.startswith('track') or line.startswith('browser'):
                continue
            if len(line.strip().split('\t')) < 4:
                log("ERROR: Input_BED_file should be annotated (i.e. has at least 4 columns)!")
                sys.exit(1)
            input_regions.append(Region(line.strip().split('\t')))

    prev_regions = []
    for cur_region in sorted(input_regions):
        # remove all previous regions before (i.e. not overlapping) cur_region
        while prev_regions:
            if not prev_regions[0].overlaps(cur_region):
                region = prev_regions.pop(0)
                sys.stdout.write(str(region))
            else:
                break
        if prev_regions:
            # splitting overlaps of cur_region with rest of prev_regions
            i = 0
            while i < len(prev_regions):
                region = prev_regions[i]
                if region.overlaps(cur_region):
                    split_regions = region.split(cur_region, key_genes)
                    if len(prev_regions) > i + 1 and split_regions[-1].overlaps(prev_regions[i + 1]):
                        prev_regions = prev_regions[:i] + split_regions[:-1] + prev_regions[i + 1:]
                        i += len(split_regions) - 1
                        cur_region = split_regions[-1]
                    else:  # no overlaps with rest of prev_regions
                        prev_regions = prev_regions[:i] + split_regions + prev_regions[i + 1:]
                        break
                else:
                    break
        else:
            prev_regions = [cur_region]
    for region in prev_regions:
        sys.stdout.write(str(region))


if __name__ == '__main__':
    main()



#!/usr/bin/env python
'''
Filters a tab-delmited file based upon configurable critera
'''

import sys, os, gzip
from .support import gzip_opener

def usage():
    print(__doc__)
    print("""\
Usage: %s -header file.txt {criteria}

Where criteria is a set of operations in the form of:
col# operation value

Eg: 
1 eq foo
Column 1 (first column) is equal to 'foo'

1 eq foo 2 lt 3
Column 1 (first column) is equal to 'foo' and column 2 is less than 3

Valid operation:
eq
ne
lt
lte
gt
gte
contains

All comment lines are printed as-is.
""" % os.path.basename(sys.argv[0]))
    sys.exit(1)
class Criteria(object):
    @staticmethod
    def parse_args(args):
        c = Criteria()
        for i in range(0,len(args), 3):
            if args[i+1] in Criteria.__dict__:
                c.add_criterion(int(args[i])-1,args[i+1],args[i+2])
            else:
                print("Unknown filter function: %s" % args[i+1])
                sys.exit(1)
        
        return c
        
        
    def __init__(self,criteria=None):
        if criteria:
            self.criteria = criteria
        else:
            self.criteria = []
    
    def add_criterion(self,col,func,arg):
        self.criteria.append((col,func,arg))
        
    def filter(self,cols):
        for col,func,arg in self.criteria:
            try:
                if not Criteria.__dict__[func](self,cols[col],arg):
                    return False
            except Exception as e:
                return False
        return True
    
    def eq(self,val,arg):
        return val == arg
    def contains(self,val,arg):
        return arg in val
    def ne(self,val,arg):
        return val != arg
    def lt(self,val,arg):
        return float(val) < float(arg)
    def lte(self,val,arg):
        return float(val) <= float(arg)
    def gt(self,val,arg):
        return float(val) > float(arg)
    def gte(self,val,arg):
        return float(val) >= float(arg)

def filter_file(fname,criteria,header):
    f = gzip_opener(fname).open()
    line_num = 0
    for line in f:
        if line[0] == '#':
            sys.stdout.write(line)
            continue
        if line_num == 0 and header:
            sys.stdout.write(line)
            line_num += 1
            continue
            
        cols = line.strip().split('\t')
        good = True
        if criteria.filter(cols):
            sys.stdout.write(line)
    if f != sys.stdin:
        f.close()

def main(argv):
    header = False
    fname = None
    criteria_args = []
    for arg in sys.argv[1:]:
        if arg == '-header':
            header = True
        elif not fname and (os.path.exists(arg) or arg == '-'):
            fname = arg
        else:
            criteria_args.append(arg)

    criteria = Criteria.parse_args(criteria_args)
    
    if not criteria or not fname:
        usage()
    
    filter_file(fname,criteria,header)
                
if __name__ == '__main__':
    main(sys.argv[1:])



#!/usr/bin/env python
'''
Adds a new constant column to each line in a tab-delimited file
'''

import sys,os

from .support import gzip_opener

def tab_tag(fname, colname, colvalue, colidx, delim='\t', noheader=False):
    f = gzip_opener(fname).open()
    header = not noheader
    for line in f:
        if line[0] == '#':
            sys.stdout.write(line)
            continue

        cols = line.rstrip('\n').split(delim)
        if header:
            cols.insert(colidx, colname)
            header = False
        else:
            cols.insert(colidx, colvalue)

        sys.stdout.write('%s\n' % '\t'.join(cols))
 
    f.close()
    
def usage(msg=""):
    if msg:
        print(msg)
    print(__doc__)
    print("""Usage: %s {opts} filename.tab tag

Note: columns start at 1

Options:
    -d delim    Use this (opposed to a tab) for the delimiter
    -name val   The name for this field (in header) (default: tag)
    -pos idx    Insert the new column as column #idx (default: 1)
    -noheader   This file doesn't have a header


""" % os.path.basename(sys.argv[0]))
    sys.exit(1)
    
def main(argv):
    fname = None
    delim = '\t'
    noheader  = False
    name = None
    tag = None
    pos = 0

    last = None

    for arg in argv:
        if arg in ['-h','--help']:
            usage()
        elif last == '-d':
            delim = arg
            last = None
        elif last == '-name':
            name = arg
            last = None
        elif last == '-pos':
            pos = int(arg) - 1
            last = None
        elif arg in ['-d', '-name', '-pos']:
            last = arg
        elif arg == '-noheader':
            noheader = True
        elif not fname and (os.path.exists(arg) or arg == '-'):
            fname = arg
        elif not tag:
            tag = arg
        else:
            usage("Unknown option: %s" % arg)
    
    if not fname or not tag:
        usage("Missing input file or tag!")

    if not name:
        name = tag

    tab_tag(fname, name, tag, pos, delim, noheader)
    
if __name__ == '__main__':
    main(sys.argv[1:])




import os
import subprocess
import traceback
from os.path import join, dirname, abspath, basename, isfile, getmtime
import sys

from pybedtools import BedTool

from ngs_utils.call_process import run
from ngs_utils.file_utils import verify_file, splitext_plus, which, can_reuse
from ngs_utils.logger import debug, warn, err, critical


def get_executable():
    sys_path = which('sambamba')
    if not sys_path:
        critical('Error: sambamba executable is not found')
    return sys_path


def index_bam(bam_fpath, sambamba=None, samtools=None):
    sambamba = sambamba or get_executable()
    indexed_bam = bam_fpath + '.bai'
    if not can_reuse(indexed_bam, cmp_f=bam_fpath, silent=True):
        # info('Indexing BAM, writing ' + indexed_bam + '...')
        cmdline = '{sambamba} index {bam_fpath}'.format(**locals())
        res = run(cmdline, output_fpath=indexed_bam, stdout_to_outputfile=False, stdout_tx=False)
        # if not isfile(indexed_bam) or getmtime(indexed_bam) < getmtime(bam_fpath):
        #     samtools = samtools or get_system_path(cnf, 'samtools')
        #     cmdline = '{samtools} index {bam_fpath}'.format(**locals())
        #     call(cnf, cmdline)
    # else:
    #     debug('Actual "bai" index exists.')


def call_sambamba(cmdl, bam_fpath, output_fpath=None, command_name='', no_index=False):
    if not no_index:
        index_bam(bam_fpath)
    sambamba = get_executable()
    run(sambamba + ' ' + cmdl, output_fpath=output_fpath)
    return output_fpath


def sambamba_depth(work_dir, bed, bam, depth_thresholds=None,
                   output_fpath=None, sample_name=None, threads=1):
    if not bam:
        return None
    sample_name = sample_name or splitext_plus(basename(bam))[0]
    depth_thresholds = depth_thresholds or []
    
    if isinstance(bed, BedTool):
        bed = bed.saveas().fn
    if not output_fpath:
        output_fpath = join(work_dir,
            splitext_plus(basename(bed))[0] + '_' + sample_name + '_sambamba_depth.txt')

    if can_reuse(output_fpath, [bam, bed]):
        return output_fpath

    thresholds_str = ''.join([' -T' + str(d) for d in depth_thresholds])
    cmdline = ('depth region -F "not duplicate and not failed_quality_control" '
               '-t {threads} -L {bed} {thresholds_str} {bam}').format(**locals())

    call_sambamba(cmdline, bam_fpath=bam, output_fpath=output_fpath)
    return output_fpath


def remove_dups(bam, output_fpath):
    cmdline = 'view --format=bam -F "not duplicate" {bam}'.format(**locals())  # -F (=not) 1024 (=duplicate)
    return call_sambamba(cmdline, bam_fpath=bam, output_fpath=output_fpath, command_name='not_duplicate')


def count_in_bam(work_dir, bam, query, dedup=False, bed=None, use_grid=False, sample_name=None, target_name=None):
    if dedup:
        query += ' and not duplicate'
    name = 'num_' + (query.replace(' ', '_') or 'reads')
    if bed is not None and isinstance(bed, BedTool):
        bed = bed.saveas().fn
    if bed is not None:
        target_name = target_name or ('target_' + basename(bed))
        name += '_on_' + target_name

    sample_name = sample_name or basename(bam)
    output_fpath = join(work_dir, sample_name + '_' + name)

    if can_reuse(output_fpath, cmp_f=bam):
        pass
    else:
        cmdline = 'view -c -F "{query}" {bam}'.format(**locals())
        if bed is not None:
            cmdline += ' -L ' + bed

        call_sambamba(cmdline, bam_fpath=bam, output_fpath=output_fpath, command_name=name)

    with open(output_fpath) as f:
        return int(f.read().strip())


def number_of_reads(work_dir, bam, dedup=False, use_grid=False, sample_name=None, reuse=False):
    return count_in_bam(work_dir, bam, '', dedup, use_grid=use_grid, sample_name=sample_name)


def number_of_mapped_reads(work_dir, bam, dedup=False, use_grid=False, sample_name=None, reuse=False):
    return count_in_bam(work_dir, bam, 'not unmapped', dedup, use_grid=use_grid, sample_name=sample_name)


def number_of_properly_paired_reads(work_dir, bam, dedup=False, use_grid=False, sample_name=None, reuse=False):
    return count_in_bam(work_dir, bam, 'proper_pair', dedup, use_grid=use_grid, sample_name=sample_name)


def number_of_dup_reads(work_dir, bam, use_grid=False, sample_name=None, reuse=False):
    return count_in_bam(work_dir, bam, 'duplicate', use_grid=use_grid, sample_name=sample_name)


def number_mapped_reads_on_target(work_dir, bed, bam, dedup=False, use_grid=False, sample_name=None, target_name=None):
    return count_in_bam(work_dir, bam, 'not unmapped', dedup, bed=bed, use_grid=use_grid, sample_name=sample_name, target_name=target_name)


# def flag_stat(cnf, bam):
#     output_fpath = join(cnf.work_dir, basename(bam) + '_flag_stats')
#     cmdline = 'flagstat {bam}'.format(**locals())
#     call_sambamba(cmdline, output_fpath=output_fpath, bam_fpath=bam, command_name='flagstat')
#     stats = dict()
#     with open(output_fpath) as f:
#         lines = f.readlines()
#         for stat, fun in [('total', number_of_reads),
#                           ('duplicates', number_of_dup_reads),  # '-f 1024'
#                           ('mapped', number_of_mapped_reads),   # '-F 4'
#                           ('properly paired', number_of_properly_paired_reads)]:  # '-f 2'
#             try:
#                 val = next(l.split()[0] for l in lines if stat in l)
#             except StopIteration:
#                 warn('Cannot extract ' + stat + ' from flagstat output ' + output_fpath + '. Trying samtools view -c...')
#                 val = None
#             else:
#                 try:
#                     val = int(val)
#                 except ValueError:
#                     warn('Cannot parse value ' + str(val) + ' from ' + stat + ' from flagstat output ' + output_fpath + '. Trying samtools view -c...')
#                     val = None
#             if val is not None:
#                 stats[stat] = val
#             else:
#                 stats[stat] = fun(cnf, bam)
#     return stats



#!/usr/bin/env python
import sys
if not ((2, 7) <= sys.version_info[:2]):
    sys.exit('Python 2.7 and 3 ares supported '
             '(you are running %d.%d.%d)' %
             (sys.version_info[0], sys.version_info[1], sys.version_info[2]))

from itertools import repeat, count
import subprocess
import sys
import getpass


example_lines = '''job-ID     prior   name       user         state submit/start at     queue                          jclass                         slots ja-task-ID
------------------------------------------------------------------------------------------------------------------------------------------------
      9606 0.86405 VFS_BxAUAg klpf990      r     03/18/2015 11:30:23 batch.q@bn0204                                                    5
       Full jobname:     VFS_BxAUAg=_bcbio
       Master Queue:     batch.q@bn0204
       Requested PE:     smp 5
       Granted PE:       smp 5
       Hard Resources:
       Soft Resources:
       Hard requested queues: batch.q
       Predecessor Jobs (request): _
       Binding:          NONE
      9670 0.00000 TARGQC_0G6 klpf990      hqw   03/18/2015 11:37:00                                                                   4
       Full jobname:     TARGQC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup
       Requested PE:     smp 4
       Hard Resources:
       Soft Resources:
       Hard requested queues: batch.q
       Predecessor Jobs (request): TC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Acrometrix-ready, NC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Acrometrix-ready, QM_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Acrometrix-ready, TC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Colo829-ready, NC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Colo829-ready, QM_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Colo829-ready, TC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Horizon-ready, NC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Horizon-ready, QM_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Horizon-ready, TC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Promega-ready, NC_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Promega-ready, QM_0G6ozA=_IDT-PanCancer_AZ1-IDT-Evaluation_nodup_Promega-ready
       Predecessor Jobs: 9662, 9668, 9244, 9544
       Binding:          NONE'''.split('\n')


rows = []
header_fields = []
cur_fields, full_name, pred_jobs = None, '', ''

def add_row(cur_fields, full_name, pred_jobs):
    if len(cur_fields) >= 9:
        job_id, prior, name, user, state, date, time, queue, slots = cur_fields[:9]
        rows.append([job_id, prior, full_name, user, state, date, time, queue, slots, pred_jobs])
    else:
        if len(cur_fields) >= 8:
            job_id, prior, name, user, state, date, time, slots = cur_fields[:8]
            queue = ''
            rows.append([job_id, prior, full_name, user, state, date, time, queue, slots, pred_jobs])
        else:
            sys.stderr.write('Line with small number of fields: ' + str(cur_fields) + '\n')
    return None, '', ''


un = getpass.getuser()
cmdl = ['qstat', '-r']
if len(sys.argv) > 1 and sys.argv[1] == '-a':
    un = ''
    cmdl.extend(['-u', '"*"'])

f = subprocess.Popen(cmdl, stdout=subprocess.PIPE).stdout
for i, l in enumerate(f):
    if i == 0:
        l = l.replace('submit/start', 'submit/date')
        header_fields = [f for f in l.split() if f not in ['jclass', 'ja-task-ID']]
        rows.append(header_fields + ['pred_jobs'])  # job-ID  prior  name  user  state  submit/start  at  queue  slots
        continue
    if i == 1:  # ----------------...
        continue

    l = l.strip()
    if un in l.strip():  # 9606 0.86405 VFS_BxAUAg klpf990      r     03/18/2015 11:30:23 batch.q@bn0204
        if cur_fields:
            cur_fields, full_name, pred_jobs = add_row(cur_fields, full_name, pred_jobs)
        cur_fields = l.split()

    elif cur_fields:
        if l.startswith('Full jobname: '):
            full_name = l.split(': ')[1].strip()

        elif l.startswith('Predecessor Jobs: '):
            pred_jobs = ' '.join(l.split(': ')[1].strip().split(', '))

if cur_fields:
    add_row(cur_fields, full_name, pred_jobs)


if len(rows) > 0:
    col_widths = repeat(0)
    try:
        from itertools import izip as zip
    except:
        pass
    for row in rows:
        col_widths = [max(len(v), w) for v, w in zip(row[:-1], col_widths)]

    line = ''
    for i, row in enumerate(rows):
        if i == 1:
            sys.stdout.write('-' * len(line) + '\n')
        for val, w in zip(row[:-1], col_widths):
            cell = val + (' ' * (w - len(val) + 2))
            sys.stdout.write(cell)
            line += cell
        sys.stdout.write(row[-1])
        line += row[-1]
        sys.stdout.write('\n')


#!/usr/bin/env python
'''
A data aware tab-delimited file viewer

Works by reading in the first few lines to determine the appropriate widths 
for each of the columns.  It will then display the data with the appropriate 
spacing to keep columns together.  If a future cell is larger than the 
predetermined size, it is truncated.

This can then be fed into something like 'less' for paging
'''

import sys,os,math
from .support import gzip_opener

def tab_view(fname,preview_lines=100,delim='\t',max_size=None, min_size=0):
    colsizes = []
    coltypes = []
    preview_buf = []
    prev_count = 0
    inpreview = True

    try:
        f = gzip_opener(fname).open()
        for line in f:
            if inpreview and line[0] == '#':
                preview_buf.append(line)
            else:
                if inpreview:
                    cols = line.rstrip().split(delim)
                
                    for i,col in enumerate(cols):
                        if len(colsizes) <= i:
                            colsizes.append(len(col))
                            coltypes.append('i')
                        elif len(col) > colsizes[i]:
                            colsizes[i] = len(col)
                        try:
                            v = int(col)
                        except:
                            coltypes[i] = 't'

                    preview_buf.append(line)
                    prev_count += 1
                    if prev_count >= preview_lines:
                        if max_size:
                            colsizes = [ min(max_size, int(math.ceil(x * 1.2))) for x in colsizes ]
                        else:
                            colsizes = [ max(min_size, int(math.ceil(x * 1.2))) for x in colsizes ]
                        for preview in preview_buf:
                            _write_cols(preview,colsizes,coltypes)
                        preview_buf = None
                        inpreview=False
                else:
                    _write_cols(line,colsizes,coltypes)
        if f != sys.stdin:
            f.close()
        if preview_buf:
            colsizes = [ int(math.ceil(x * 1.2)) for x in colsizes ]
            for preview in preview_buf:
                _write_cols(preview,colsizes,coltypes)
    except KeyboardInterrupt:
        print("")
        pass
    except IOError:
        print("")
        pass
    

def _write_cols(line,colsizes,coltypes):
    cols = line.rstrip().split('\t')

    if len(cols) == 1:
        sys.stdout.write('%s\n' % cols[0])
        return

    while len(cols) < len(colsizes):
        cols.append('')
    

    for i,col in enumerate(cols):
        if i>=len(colsizes):
            val = '%s' % col # for headers w/o values
        elif len(col) > colsizes[i]:  
            # if too big, show as much as possible, and indicate the 
            # truncation with '$'
            val = '%s$' % col[:colsizes[i]-1]
        elif coltypes[i] == 'i':
            # numbers right justified
            val = col.rjust(colsizes[i])
        else:
            # text left justified
            val = col.ljust(colsizes[i])
        
        sys.stdout.write(val)
        if i < (len(cols) - 1):
            sys.stdout.write('  ')
    sys.stdout.write('\n')
    
def usage():
    print(__doc__)
    print("""Usage: %s {opts} filename.tab

Options:
-l lines    The number of lines to read in to estimate the size of a column.
            [default 100]
-d delim    Use this (opposed to a tab) for the delimiter

-max size   The maximum length of a column (default: unlimited)
-min size   The minimum length of a column (default: 0)

""" % os.path.basename(sys.argv[0]))
    sys.exit(1)
    
def main(argv):
    fname = '-'
    lines = 100
    delim = '\t'
    max_size = None
    min_size = 0
    last = None
    for arg in argv:
        if arg in ['-h','--help']:
            usage()
        elif last == '-l':
            lines = int(arg)
            last = None
        elif last == '-d':
            delim = arg
            last = None
        elif last == '-min':
            min_size = int(arg)
            last = None
        elif last == '-max':
            max_size = int(arg)
            last = None
        elif arg in ['-l','-d','-max','-min']:
            last = arg
        elif arg == '-':
            fname = '-'
        elif os.path.exists(arg):
            fname = arg
        
    tab_view(fname,lines,delim,max_size, min_size)
    
if __name__ == '__main__':
    main(sys.argv[1:])




#!/usr/bin/env python
import sys
py_v = sys.version_info[:2]
if not (py_v == (2, 7) or py_v >= (3, 3)):
    sys.exit('Only Python 2.7 or 3.3 and up are supported. Current version: ' + '.'.join(py_v))
    
from os.path import join
from ngs_utils import setup_utils


import ngs_utils
package_name = ngs_utils.__name__


version = setup_utils.init(package_name, package_name, __file__)


from setuptools import setup
setup(
    name=package_name,
    version=version,
    author='Vlad Saveliev',
    author_email='vlad.saveliev@astrazeneca.com',
    description='Utils for NGS pipelines by Vlad Saveliev',
    keywords='bioinformatics',
    url='https://github.com/vladsaveliev/NGS_Utils',
    license='GPLv3',
    packages=[
        package_name,
        'tab_utils'
    ],
    package_data={
        package_name: [
        ] + setup_utils.find_package_files('reporting', package_name, skip_exts=['.sass', '.coffee'])
          + setup_utils.find_package_files('reference_data', package_name)
    },
    include_package_data=True,
    zip_safe=False,
    install_requires=setup_utils.get_reqs(),
    setup_requires=['numpy'],
    scripts=[path for path in
         [join('scripts', fn) for fn in [
             'tabutils',
             'standardize_bed.py',
             'split_bed.py',
             'qstat.py',
             'sort_bed.py',
             'bed_file_from_gene_list.py',
             'html_to_base64.py',
             'group_and_merge_by_gene.py'
         ]]],
    classifiers=[
        'Environment :: Console',
        'Environment :: Web Environment',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: JavaScript',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
    ],
)



from ngs_utils.file_utils import verify_file, adjust_path
from ngs_utils.logger import critical, err


def verify_bam(fpath, description='', is_critical=False, silent=False):
    if not verify_file(fpath, description, is_critical=is_critical, silent=silent):
        return None

    fpath = adjust_path(fpath)

    logfn = critical if is_critical else err
    if not fpath.endswith('.bam'):
        logfn('The file ' + fpath + ' is supposed to be BAM but does not have the .bam '
            'extension. Please, make sure you pass proper file.')
        return None

    # TODO: check if binary

    return fpath





#!/usr/bin/env python
from os.path import basename

import sys
from optparse import OptionParser

from ngs_utils.file_utils import adjust_path
from ngs_utils.logger import critical
from ngs_utils.bed_utils import verify_bed, sort_bed


def main():
    parser = OptionParser(usage='Usage: ' + basename(__file__) + ' -o Output_BED_file -g hg19 Input_BED_file')
    parser.add_option('-o', '--output-bed', dest='output_fpath')
    parser.add_option('-g', '--genome', dest='genome')
    parser.add_option('--fai', dest='fai_fpath')
    (opts, args) = parser.parse_args(sys.argv[1:])

    if len(args) < 1:
        parser.print_help(file=sys.stderr)
        sys.exit(1)

    if not opts.output_fpath:
        critical(parser.usage)

    sort_bed(input_bed_fpath=verify_bed(args[0], is_critical=True),
             output_bed_fpath=adjust_path(opts.output_fpath),
             fai_fpath=adjust_path(opts.fai_fpath),
             genome=opts.genome)


if __name__ == '__main__':
    main()
